==> owncloud-4.5.7.tgz: owncloud/apps/user_ldap/l10n/zh_CN.GB2312.php <==
<?php $TRANSLATIONS = array(
"Host" => "主机",
"You can omit the protocol, except you require SSL. Then start with ldaps://" => "您可以忽略协议，除非您需要 SSL。然后用 ldaps:// 开头",
"Base DN" => "基本判别名",
"You can specify Base DN for users and groups in the Advanced tab" => "您可以在高级选项卡中为用户和群组指定基本判别名",
"User DN" => "用户判别名",
"The DN of the client user with which the bind shall be done, e.g. uid=agent,dc=example,dc=com. For anonymous access, leave DN and Password empty." => "客户机用户的判别名，将用于绑定，例如 uid=agent, dc=example, dc=com。匿名访问请留空判别名和密码。",
"Password" => "密码",
"For anonymous access, leave DN and Password empty." => "匿名访问请留空判别名和密码。",
"User Login Filter" => "用户登录过滤器",
"Defines the filter to apply, when login is attempted. %%uid replaces the username in the login action." => "定义尝试登录时要应用的过滤器。用 %%uid 替换登录操作中使用的用户名。",
"use %%uid placeholder, e.g. \"uid=%%uid\"" => "使用 %%uid 占位符，例如 \"uid=%%uid\"",
"User List Filter" => "用户列表过滤器",
"Defines the filter to apply, when retrieving users." => "定义撷取用户时要应用的过滤器。",
"without any placeholder, e.g. \"objectClass=person\"." => "不能使用占位符，例如 \"objectClass=person\"。",
"Group Filter" => "群组过滤器",
"Defines the filter to apply, when retrieving groups." => "定义撷取群组时要应用的过滤器",
"without any placeholder, e.g. \"objectClass=posixGroup\"." => "不能使用占位符，例如 \"objectClass=posixGroup\"。",
"Port" => "端口",
"Base User Tree" => "基本用户树",
"Base Group Tree" => "基本群组树",
"Group-Member association" => "群组-成员组合",
"Use TLS" => "使用 TLS",
"Do not use it for SSL connections, it will fail." => "不要使用它进行 SSL 连接，会失败的。",
"Case insensitve LDAP server (Windows)" => "大小写不敏感的 LDAP 服务器 (Windows)",
"Turn off SSL certificate validation." => "关闭 SSL 证书校验。",
"If connection only works with this option, import the LDAP server's SSL certificate in your ownCloud server." => "如果只有使用此选项才能连接，请导入 LDAP 服务器的 SSL 证书到您的 ownCloud 服务器。",
"Not recommended, use for testing only." => "不推荐，仅供测试",
"User Display Name Field" => "用户显示名称字段",
"The LDAP attribute to use to generate the user`s ownCloud name." => "用于生成用户的 ownCloud 名称的 LDAP 属性。",
"Group Display Name Field" => "群组显示名称字段",
"The LDAP attribute to use to generate the groups`s ownCloud name." => "用于生成群组的 ownCloud 名称的 LDAP 属性。",
"in bytes" => "以字节计",
"in seconds. A change empties the cache." => "以秒计。修改会清空缓存。",
"Leave empty for user name (default). Otherwise, specify an LDAP/AD attribute." => "用户名请留空 (默认)。否则，请指定一个 LDAP/AD 属性。",
"Help" => "帮助"
);

==> owncloud-5.0.9.tgz: owncloud/apps/user_ldap/l10n/zh_CN.GB2312.php <==
<?php $TRANSLATIONS = array(
"Deletion failed" => "删除失败",
"Host" => "主机",
"You can omit the protocol, except you require SSL. Then start with ldaps://" => "您可以忽略协议，除非您需要 SSL。然后用 ldaps:// 开头",
"Base DN" => "基本判别名",
"You can specify Base DN for users and groups in the Advanced tab" => "您可以在高级选项卡中为用户和群组指定基本判别名",
"User DN" => "用户判别名",
"The DN of the client user with which the bind shall be done, e.g. uid=agent,dc=example,dc=com. For anonymous access, leave DN and Password empty." => "客户机用户的判别名，将用于绑定，例如 uid=agent, dc=example, dc=com。匿名访问请留空判别名和密码。",
"Password" => "密码",
"For anonymous access, leave DN and Password empty." => "匿名访问请留空判别名和密码。",
"User Login Filter" => "用户登录过滤器",
"Defines the filter to apply, when login is attempted. %%uid replaces the username in the login action." => "定义尝试登录时要应用的过滤器。用 %%uid 替换登录操作中使用的用户名。",
"use %%uid placeholder, e.g. \"uid=%%uid\"" => "使用 %%uid 占位符，例如 \"uid=%%uid\"",
"User List Filter" => "用户列表过滤器",
"Defines the filter to apply, when retrieving users." => "定义撷取用户时要应用的过滤器。",
"without any placeholder, e.g. \"objectClass=person\"." => "不能使用占位符，例如 \"objectClass=person\"。",
"Group Filter" => "群组过滤器",
"Defines the filter to apply, when retrieving groups." => "定义撷取群组时要应用的过滤器",
"without any placeholder, e.g. \"objectClass=posixGroup\"." => "不能使用占位符，例如 \"objectClass=posixGroup\"。",
"Port" => "端口",
"Use TLS" => "使用 TLS",
"Case insensitve LDAP server (Windows)" => "大小写不敏感的 LDAP 服务器 (Windows)",
"Turn off SSL certificate validation." => "关闭 SSL 证书校验。",
"If connection only works with this option, import the LDAP server's SSL certificate in your ownCloud server." => "如果只有使用此选项才能连接，请导入 LDAP 服务器的 SSL 证书到您的 ownCloud 服务器。",
"Not recommended, use for testing only." => "不推荐，仅供测试",
"in seconds. A change empties the cache." => "以秒计。修改会清空缓存。",
"User Display Name Field" => "用户显示名称字段",
"The LDAP attribute to use to generate the user`s ownCloud name." => "用于生成用户的 ownCloud 名称的 LDAP 属性。",
"Base User Tree" => "基本用户树",
"Group Display Name Field" => "群组显示名称字段",
"The LDAP attribute to use to generate the groups`s ownCloud name." => "用于生成群组的 ownCloud 名称的 LDAP 属性。",
"Base Group Tree" => "基本群组树",
"Group-Member association" => "群组-成员组合",
"in bytes" => "以字节计",
"Leave empty for user name (default). Otherwise, specify an LDAP/AD attribute." => "用户名请留空 (默认)。否则，请指定一个 LDAP/AD 属性。",
"Help" => "帮助"
);
